@@ -23,7 +23,7 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
+#include <tdelocale.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -155,7 +155,7 @@ void Activity::setLabelText(const TQString& idx, const TQString& txt) const
   if(w) {
     w->setText(txt);
   } else {
-    qDebug("Unknown TQLabel named '%s'", idx.data());
+    tqDebug("Unknown TQLabel named '%s'", idx.data());
   }
 }
 
@@ -484,7 +484,7 @@ bool Reinvest::createTransaction(MyMoneyTransaction& t, MyMoneySplit& s0, MyMone
     return false;
 
   if(interestSplits.count() != 1) {
-    qDebug("more or less than one interest split in Reinvest::createTransaction. Not created.");
+    tqDebug("more or less than one interest split in Reinvest::createTransaction. Not created.");
     return false;
   }
 
