@@ -40,8 +40,8 @@
 // (e.g. MyMoneyAccount::Checkings) into their text representation.  We also
 // use that text representation in the core data structure of the report. (Ace)
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kcalendarsystem.h>
 
@@ -72,7 +72,7 @@ Debug::Debug( const TQString& _name ): m_methodName( _name ), m_enabled( m_sEnab
 
   if (m_enabled)
   {
-    qDebug( "%s%s(): ENTER", m_sTabs.latin1(), m_methodName.latin1() );
+    tqDebug( "%s%s(): ENTER", m_sTabs.latin1(), m_methodName.latin1() );
     m_sTabs.append("--");
   }
 }
@@ -82,7 +82,7 @@ Debug::~Debug()
   if ( m_enabled )
   {
     m_sTabs.remove(0,2);
-    qDebug( "%s%s(): EXIT", m_sTabs.latin1(), m_methodName.latin1() );
+    tqDebug( "%s%s(): EXIT", m_sTabs.latin1(), m_methodName.latin1() );
 
     if (m_methodName == m_sEnableKey)
       m_enabled = false;
@@ -92,7 +92,7 @@ Debug::~Debug()
 void Debug::output( const TQString& _text )
 {
   if ( m_enabled )
-    qDebug( "%s%s(): %s", m_sTabs.latin1(), m_methodName.latin1(), _text.latin1() );
+    tqDebug( "%s%s(): %s", m_sTabs.latin1(), m_methodName.latin1(), _text.latin1() );
 }
 
 PivotTable::PivotTable( const MyMoneyReport& _config_f ):
@@ -190,7 +190,7 @@ void PivotTable::init(void)
   try {
     transactions = file->transactionList(m_config_f);
   } catch(MyMoneyException *e) {
-    qDebug("ERR: %s thrown in %s(%ld)", e->what().data(), e->file().data(), e->line());
+    tqDebug("ERR: %s thrown in %s(%ld)", e->what().data(), e->file().data(), e->line());
     throw e;
   }
   DEBUG_OUTPUT(TQString("Found %1 matching transactions").arg(transactions.count()));
@@ -332,7 +332,7 @@ void PivotTable::init(void)
           if(value != MyMoneyMoney::autoCalc) {
             value = value * reverse;
           } else {
-            qDebug("PivotTable::PivotTable(): This must not happen");
+            tqDebug("PivotTable::PivotTable(): This must not happen");
             value = MyMoneyMoney();  // keep it 0 so far
           }
 
@@ -436,7 +436,7 @@ void PivotTable::collapseColumns(void)
   {
     unsigned sourcemonth = (m_config_f.isColumnsAreDays())
       // use the user's locale to determine the week's start
-      ? (m_beginDate.dayOfWeek() + 8 - KGlobal::locale()->weekStartDay()) % 7
+      ? (m_beginDate.dayOfWeek() + 8 - TDEGlobal::locale()->weekStartDay()) % 7
       : m_beginDate.month();
     unsigned sourcecolumn = 1;
     unsigned destcolumn = 1;
@@ -544,7 +544,7 @@ void PivotTable::calculateColumnHeadings(void)
       unsigned column = 1;
       while ( column++ < m_numColumns )
       {
-        TQString heading = KGlobal::locale()->calendar()->monthName(columnDate.month(), columnDate.year(), true) + " " + TQString::number(columnDate.day());
+        TQString heading = TDEGlobal::locale()->calendar()->monthName(columnDate.month(), columnDate.year(), true) + " " + TQString::number(columnDate.day());
         columnDate = columnDate.addDays(1);
         m_columnHeadings.append( heading);
       }
@@ -555,16 +555,16 @@ void PivotTable::calculateColumnHeadings(void)
       TQDate prv = m_beginDate;
 
       // use the user's locale to determine the week's start
-      unsigned dow = (day.dayOfWeek() +8 -KGlobal::locale()->weekStartDay())%7;
+      unsigned dow = (day.dayOfWeek() +8 -TDEGlobal::locale()->weekStartDay())%7;
 
       while (day <= m_endDate)
       {
         if (((dow % columnpitch) == 0) || (day == m_endDate))
         {
           m_columnHeadings.append(TQString("%1&nbsp;%2 - %3&nbsp;%4")
-            .arg(KGlobal::locale()->calendar()->monthName(prv.month(), prv.year(), true))
+            .arg(TDEGlobal::locale()->calendar()->monthName(prv.month(), prv.year(), true))
             .arg(prv.day())
-            .arg(KGlobal::locale()->calendar()->monthName(day.month(), day.year(), true))
+            .arg(TDEGlobal::locale()->calendar()->monthName(day.month(), day.year(), true))
             .arg(day.day()));
           prv = day.addDays(1);
         }
@@ -592,9 +592,9 @@ void PivotTable::calculateColumnHeadings(void)
       unsigned column = 1;
       while ( column++ < m_numColumns )
       {
-        TQString heading = KGlobal::locale()->calendar()->monthName(1+segment*columnpitch, 2000, true);
+        TQString heading = TDEGlobal::locale()->calendar()->monthName(1+segment*columnpitch, 2000, true);
         if ( columnpitch != 1 )
-          heading += "-" + KGlobal::locale()->calendar()->monthName((1+segment)*columnpitch, 2000, true);
+          heading += "-" + TDEGlobal::locale()->calendar()->monthName((1+segment)*columnpitch, 2000, true);
         if ( includeyear )
           heading += " " + TQString::number(year);
         m_columnHeadings.append( heading);
@@ -761,7 +761,7 @@ void PivotTable::calculateRunningSums( void )
 MyMoneyMoney PivotTable::cellBalance(const TQString& outergroup, const ReportAccount& _row, unsigned _column, bool budget)
 {
   if(m_runningSumsCalculated) {
-    qDebug("You must not call PivotTable::cellBalance() after calling PivotTable::calculateRunningSums()");
+    tqDebug("You must not call PivotTable::cellBalance() after calling PivotTable::calculateRunningSums()");
     throw new MYMONEYEXCEPTION(TQString("You must not call PivotTable::cellBalance() after calling PivotTable::calculateRunningSums()"));
   }
 
@@ -1578,7 +1578,7 @@ TQString PivotTable::renderHTML( void ) const
 
   //actual dates of the report
   result += TQString("<div class=\"subtitle\">");
-  result += i18n("Report date range", "%1 through %2").arg(KGlobal::locale()->formatDate(m_config_f.fromDate(), true)).arg(KGlobal::locale()->formatDate(m_config_f.toDate(), true));
+  result += i18n("Report date range", "%1 through %2").arg(TDEGlobal::locale()->formatDate(m_config_f.fromDate(), true)).arg(TDEGlobal::locale()->formatDate(m_config_f.toDate(), true));
   result += TQString("</div>\n");
   result += TQString("<div class=\"gap\">&nbsp;</div>\n");
 
@@ -2616,4 +2616,3 @@ void PivotTable::includeInvestmentSubAccounts()
 }
 
 } // namespace
-// vim:cin:si:ai:et:ts=2:sw=2:
