@@ -26,10 +26,10 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
-#include <klistview.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
 #include <kdebug.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -172,7 +172,7 @@ void KMyMoneyCombo::mousePressEvent(TQMouseEvent *e)
     m_timer.stop();
     m_completion->slotMakeCompletion("");
   } else {
-    KConfig config( "kcminputrc", true );
+    TDEConfig config( "kcminputrc", true );
     config.setGroup("KDE");
     m_timer.start(config.readNumEntry("DoubleClickInterval", 400), true);
   }
